@@ -32,7 +32,23 @@ public:
         Auto = 0,
         Breadcrumb,
         Titles,
-        TabBar
+        TabBar,
+        ToolBar, ///@since 5.48
+        None ///@since 5.48
+    };
+};
+
+class MessageType : public QObject
+{
+    Q_OBJECT
+    Q_ENUMS(Type)
+
+public:
+    enum Type {
+        Information = 0,
+        Positive,
+        Warning,
+        Error
     };
 };
 
